import { useEffect, useState } from 'react';
import { Table, Spinner } from 'react-bootstrap';
import ProductRow from './ProductRow.js';

const AdminView = ({ data, fetchData }) => {
  const [products, setProducts] = useState([]);
  const [isLoading, setIsLoading] = useState(true); // State variable to track loading status

  useEffect(() => {
    const productListing = data.map(product => (
      <tr key={product._id}>
        <ProductRow product={product} fetchData={fetchData} /> 
      </tr>
    ));

    setProducts(productListing);
    setIsLoading(false); // Set loading to false after products are fetched

  }, [data, fetchData]);

  return (
    <Table striped bordered hover responsive className="h5 text-center">
      <thead className="text-center">
        <tr>
          <th className="h3 col-id">ID</th>
          <th className="h3 col-prod-name">Name</th>
          <th className="h3">Description</th>
          <th className="h3">Price</th>
          <th className="h3">Inventory</th>
          <th className="h3">Availability</th>
          <th colSpan={2} className="h3 col-actions">Actions</th>
        </tr>
      </thead>
      <tbody>
        {isLoading ? ( // Show spinner if loading
          <tr>
            <td colSpan={7} className="text-center">
              <Spinner animation="border" role="status">
                <span className="visually-hidden">Loading...</span>
              </Spinner>
            </td>
          </tr>
        ) : (
          products // Show product rows if not loading
        )}
      </tbody>
    </Table>
  );
};

export default AdminView;
