import { useState, useEffect } from 'react';
import ProductCard from '../components/ProductCard.js';

const ProductSearch = () => {
  const [productName, setProductName] = useState('');
  const [searchResults, setSearchResults] = useState([]);
  const [showNoResultsMessage, setShowNoResultsMessage] = useState(false);

  const handleSearch = async () => {
    try {
      const response = await fetch(`${process.env.REACT_APP_API_BASE_URL}/products/search`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ productName }),
      });

      if (response.ok) {
        const data = await response.json();
        setSearchResults(data.products);
        setShowNoResultsMessage(data.products.length === 0); // Update message visibility
      } else {
        // const errorData = await response.json();
        setSearchResults([]);
        // Handle other error cases if needed
      }
    } catch (error) {
      console.error('Error searching product:', error);
      setSearchResults([]);
    }
  };

  useEffect(() => {
    // Initial search on component mount
    handleSearch();
  }, []); // Empty dependency array means this effect runs only once on mount

  return (
    <div className="container fs-2 d-flex flex-column align-items-center">
      <h1 className="text-center mt-5 headers">Search Products</h1>
      <div className="form-group col-5">
        <label className="my-2">Product Name:</label>
        <input
          type="text"
          className="form-control"
          value={productName}
          onChange={(e) => {
            setProductName(e.target.value);
            handleSearch(); // Trigger search on every input change
          }}
        />
      </div>

      {searchResults.length > 0 && (
        <div>
          <h3 className = "text-center my-5">Search Results:</h3>
          <ul>
            {searchResults.map((item) => (
              <ProductCard prodProp={item} key={item._id} />
            ))}
          </ul>
        </div>
      )}

      {showNoResultsMessage && (
        <div className="no-results-message">
          <p>Sorry, no products found for the given search.</p>
        </div>
      )}
    </div>
  );
};

export default ProductSearch;
