import { useState, useEffect, useContext } from 'react';
import Swal from 'sweetalert2';

import ProfileContext from "../pages/ProfileContext.js";

const UpdateProfile = ({fetchProfile}) => {
  const [firstName, setFirstName] = useState('');
  const [lastName, setLastName] = useState('');
  const [mobileNo, setMobileNo] = useState('');
  const [message, setMessage] = useState(null);

  const [isDisabled, setIsDisabled] = useState(true);

  const { setIsVisibleUpdateBox } = useContext(ProfileContext);

  useEffect(() => {
        if(firstName.length === 0 || lastName === 0 || mobileNo === 0){
          setIsDisabled(true);
        }else{
          setIsDisabled(false);
        }

    }, [firstName, lastName, mobileNo])

  const updateProfile = async () => {
    try {
      const token = localStorage.getItem('token');
      const apiUrl = `${process.env.REACT_APP_API_BASE_URL}/users/update-profile`;

      const response = await fetch(apiUrl, {
        method: 'PUT',
        headers: {
          'Content-Type': 'application/json',
          Authorization: `Bearer ${token}`,
        },
        body: JSON.stringify({ firstName, lastName, mobileNo }),
      });

      // const data = await response.json();

      if (response.ok) {
        Swal.fire({
            title: "Profile updated successfully!",
            icon: "success"
        })

        fetchProfile();

      } else {
        Swal.fire({
            title: 'Error in updating!',
            icon: "error"
        })
      }

      setFirstName('');
      setLastName('');
      setMobileNo('');
      
    } catch (error) {
      console.error('Error updating profile:', error);
      setMessage('An error occurred while updating the profile.');
    }
  };

  return (
    <div className="container p-5 forms d-flex flex-column align-items-center">
      <h2>Update Profile</h2>
      <div className="mb-3 col-10">
        <label htmlFor="firstName" className="form-label">
          First Name
        </label>
        <input
          type="text"
          className="form-control"
          id="firstName"
          value={firstName}
          onChange={(e) => setFirstName(e.target.value)}
        />
      </div>
      <div className="mb-3 col-10">
        <label htmlFor="lastName" className="form-label">
          Last Name
        </label>
        <input
          type="lastName"
          className="form-control"
          id="lastName"
          value={lastName}
          onChange={(e) => setLastName(e.target.value)}
        />
      </div>
      <div className="mb-3 col-10">
        <label htmlFor="mobileNo" className="form-label">
          Mobile Number
        </label>
        <input
          type="Number"
          className="form-control"
          id="mobileNo"
          value={mobileNo}
          onChange={(e) => setMobileNo(e.target.value)}
        />
      </div>
      {message && <div className="alert alert-info">{message}</div>}

      <div className="container col-8 mt-3 d-flex justify-content-around">
        <button
          type="button"
          className="btn btn-submit nes-btn"
          disabled = {isDisabled}
          onClick={() => {
            updateProfile();
            setIsVisibleUpdateBox(false);
          }}
        >
          Update
        </button>
        {message && <div className="mt-3">{message}</div>}

        <button
          type="button"
          className="btn btn-submit nes-btn"
          onClick={() => setIsVisibleUpdateBox(false)}
        >
          Cancel
        </button>
      </div>

    </div>
  );
};

export default UpdateProfile;
