import { useState, useEffect, useContext } from 'react';
import { Container, Card, Button, Row, Col } from 'react-bootstrap';

import {useParams} from 'react-router-dom';
import UserContext from "../UserContext.js";

import Swal from "sweetalert2";

import AddToCartModal from '../components/AddToCartModal.js'

export default function ProductView() {
	const [name, setName] = useState("");
	const [description, setDescription] = useState("");
	const [price, setPrice] = useState(0);

	const {productId} = useParams();

	const { user } = useContext(UserContext);

	const orderedItems = [{
		productId: productId,
		quantity: 1
	}]

	useEffect(() => {
		fetch(`${process.env.REACT_APP_API_BASE_URL}/products/${productId}`)
		.then(result => result.json())
		.then(data => {

			setName(data.name);
			setDescription(data.description);
			setPrice(data.price);
		})
	}, [productId]);



	const buyNow = () => {
		
		if (!user || user.isAdmin == null) {
		    Swal.fire({
		        title: "Authentication error",
		        icon: "error",
		        text: "Please log in to proceed with the checkout."
		    });
		    return;

		} else if (user.isAdmin) {

			Swal.fire({
						title: "Action forbidden",
						icon: "error",
						text: "Only non-admin users can checkout products."
					})
			return;
		}

			fetch(`${process.env.REACT_APP_API_BASE_URL}/products/create-order`, {
				method : "POST",
				headers: {
					Authorization: `Bearer ${localStorage.getItem("token")}`,
					"Content-Type" : "application/json"
				},
				body: JSON.stringify({
					orderedItems : orderedItems
				})
			}).then(result => result.json())
			.then(data => {

				if (data) {

					Swal.fire({
						title: "Order succesful!",
						icon: "success",
						text: "Product successfully ordered."
					})
				}else{
					Swal.fire({
						title: "Something went wrong",
						icon: "error",
						text: "Please try again"
					})
				}
			})

	}

	return(
		<Container className="mt-5">
			<Row>
				<Col lg={{ span: 6, offset: 3 }}>
					<Card>
						<Card.Body className="text-center fs-5">
							<Card.Title className="display-3">{name}</Card.Title>
							<Card.Subtitle className='fs-3'>Description:</Card.Subtitle>
							<Card.Text>{description}</Card.Text>
							<Card.Subtitle className='fs-3'>Price:</Card.Subtitle>
							<Card.Text>{parseFloat(price).toLocaleString('en-PH', { style: 'currency', currency: 'PHP' })}</Card.Text>
							<div className="my-5 col-6 mx-auto d-flex justify-content-around">
								<Button className="nes-btn btn-submit" onClick = {() => buyNow()} >Checkout</Button>
								<AddToCartModal productId = {productId} />
							</div>
						</Card.Body>        
					</Card>
				</Col>
			</Row>
		</Container>
		)
}